@@ -1,7 +1,7 @@
-
 test_that("tangram", {
-
-  scene <- system.file("examples/tangram/www/scene.yaml", package = "leaflet.extras2")
+  scene <- system.file("examples/tangram/www/scene.yaml",
+    package = "leaflet.extras2"
+  )
 
   m <- leaflet() %>%
     addTangram(scene = scene, group = "tangram") %>%
@@ -10,26 +10,24 @@ test_that("tangram", {
 
   deps <- findDependencies(m)
   expect_equal(deps[[length(deps)]]$name, "lfx-tangram")
-  expect_equal(m$x$calls[[length(m$x$calls)]]$method,
-               "addTangram")
-
+  expect_equal(
+    m$x$calls[[length(m$x$calls)]]$method,
+    "addTangram"
+  )
 })
 
 test_that("tangram-error", {
-
   expect_error(
-    leaflet()  %>%
+    leaflet() %>%
       addTangram()
   )
   expect_error(
-    leaflet()  %>%
+    leaflet() %>%
       addTangram(scene = NULL)
   )
 
   expect_error(
-    leaflet()  %>%
+    leaflet() %>%
       addTangram(scene = "scene")
   )
-
 })
-
